@@ -3,6 +3,7 @@
 //! Please refer to the other chapters of the help for documentation of the functions.
 use super::*;
 use basic_dsp_vector::*;
+use basic_dsp_vector::meta;
 use basic_dsp_vector::conv_types::*;
 use num_complex::*;
 use std::slice;
@@ -64,6 +65,41 @@ pub extern "C" fn new_with_performance_options64(is_complex: i32,
 
 }
 
+#[no_mangle]
+pub extern "C" fn new_with_detailed_performance_options64(is_complex: i32,
+                                                 domain: i32,
+                                                 init_value: f64,
+                                                 length: usize,
+                                                 delta: f64,
+                                                 core_limit: usize,
+                                                  med_dual_core_threshold: usize,
+                                                  med_multi_core_threshold: usize,
+                                                  large_dual_core_threshold: usize,
+                                                  large_multi_core_threshold: usize)
+                                                 -> VecBox {
+    let domain = if domain == 0 {
+        DataDomain::Time
+    } else {
+        DataDomain::Frequency
+    };
+
+    let mut vector = Box::new(VecBuf {
+        vec: vec!(init_value; length).to_gen_dsp_vec(is_complex != 0, domain),
+        buffer: SingleBuffer::new(),
+    });
+    vector.vec.set_delta(delta);
+    let multicore_settings =
+        MultiCoreSettings::with_thresholds(
+            core_limit,
+            med_dual_core_threshold,
+            med_multi_core_threshold,
+            large_dual_core_threshold,
+            large_multi_core_threshold);
+    vector.vec.set_multicore_settings(multicore_settings);
+    vector
+
+}
+
 #[no_mangle]
 pub extern "C" fn get_value64(vector: &VecBuf, index: usize) -> f64 {
     vector.vec[index]
@@ -148,7 +184,7 @@ pub extern "C" fn real_dot_product64(vector: &VecBuf,
                                      operand: &VecBuf)
                                      -> ScalarInteropResult<f64> {
     vector.convert_scalar(|v| {
-        DotProductOps::<GenDspVec<Vec<f64>, f64>, f64, f64, RealOrComplexData, TimeOrFrequencyData>::dot_product(v, &operand.vec)
+        DotProductOps::<GenDspVec<Vec<f64>, f64>, f64, f64, meta::RealOrComplex, meta::TimeOrFreq>::dot_product(v, &operand.vec)
     },
     0.0)
 }
@@ -158,7 +194,7 @@ pub extern "C" fn complex_dot_product64(vector: &VecBuf,
                                         operand: &VecBuf)
                                         -> ScalarInteropResult<Complex64> {
     vector.convert_scalar(|v| {
-        DotProductOps::<GenDspVec<Vec<f64>, f64>, Complex64, f64, RealOrComplexData, TimeOrFrequencyData>::dot_product(v, &operand.vec)
+        DotProductOps::<GenDspVec<Vec<f64>, f64>, Complex64, f64, meta::RealOrComplex, meta::TimeOrFreq>::dot_product(v, &operand.vec)
     },
     Complex64::new(0.0, 0.0))
 }
@@ -199,7 +235,7 @@ pub extern "C" fn real_dot_product_prec64(vector: &VecBuf,
                                           operand: &VecBuf)
                                           -> ScalarInteropResult<f64> {
     vector.convert_scalar(|v| {
-        PreciseDotProductOps::<GenDspVec<Vec<f64>, f64>, f64, f64, RealOrComplexData, TimeOrFrequencyData>::dot_product_prec(v, &operand.vec)
+        PreciseDotProductOps::<GenDspVec<Vec<f64>, f64>, f64, f64, meta::RealOrComplex, meta::TimeOrFreq>::dot_product_prec(v, &operand.vec)
     },
     0.0)
 }
@@ -209,7 +245,7 @@ pub extern "C" fn complex_dot_product_prec64(vector: &VecBuf,
                                              operand: &VecBuf)
                                              -> ScalarInteropResult<Complex64> {
     vector.convert_scalar(|v| {
-        PreciseDotProductOps::<GenDspVec<Vec<f64>, f64>, Complex64, f64, RealOrComplexData, TimeOrFrequencyData>::dot_product_prec(v, &operand.vec)
+        PreciseDotProductOps::<GenDspVec<Vec<f64>, f64>, Complex64, f64, meta::RealOrComplex, meta::TimeOrFreq>::dot_product_prec(v, &operand.vec)
     },
     Complex64::new(0.0, 0.0))
 }
